/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  | Copyright (C) 2017 OpenCFD Ltd.
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "argList.H"
#include "fvMesh.H"
#include "volFields.H"
#include "surfaceFields.H"
#include "fvcSurfaceIntegrate.H"


using namespace Foam;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Main program:

int main(int argc, char *argv[])
{

    #include "setRootCase.H"
    #include "createTime.H"

    Info<< "Create mesh, no clear-out\n" << endl;
    fvMesh mesh
    (
        IOobject
        (
            fvMesh::defaultRegion,
            runTime.timeName(),
            runTime,
            IOobject::MUST_READ
        )
    );

volVectorField CC = mesh.C();
//volVectorField::Internal CC_Internal = mesh.C().internalField();
Info<< "CC:" << CC << endl;
Info<< "CC x coor:" << CC.component(0) << endl;


Info<< "cell volume: "<< mesh.V() << endl;
//Info<< "cell volume.field() " << mesh.V().field() << endl;
Info<< "face area vector:" << mesh.Sf() << endl;

surfaceVectorField faceVector = mesh.Sf();
Info << "faceVector: " << faceVector << endl << endl;

volScalarField surfaceSumX = 0.5*fvc::surfaceSum(mag(faceVector.component(0)));
Info << "surfaceSumX: " << surfaceSumX << endl <<endl;

scalarField surfaceSumY = 0.5*fvc::surfaceSum(mag(faceVector.component(1)));
Info << "surfaceSumY: " << surfaceSumY << endl <<endl;

volScalarField surfaceSumZ = 0.5*fvc::surfaceSum(mag(faceVector.component(2)));
Info << "surfaceSumZ: " << surfaceSumZ << endl <<endl;

volScalarField::Internal cellVolume = mesh.V();
Info << "cellVolume: " << cellVolume << endl << endl;    

volScalarField::Internal deltaX = mesh.V()/surfaceSumX;
Info << "deltaX: " <<  deltaX << endl;

scalarField deltaY = cellVolume/surfaceSumY;
Info << "deltaY: " <<  deltaY << endl;

scalarField deltaZ = cellVolume/surfaceSumZ;
Info << "deltaZ: " <<  deltaZ << endl;

    return 0;
}


// ************************************************************************* //
